Main GUI element - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

# App

App([theme]) -> App widget

This is actually a container widget with function for running itself and all widgets in it. It also has functions for parsing and using themes. Applications may only have one App instance (this may change in the future).

### Example of use

    myapp = App()

    mywidget = Widget()
    myapp.add(mywidget)

    while True:
        events = pygame.event.get() # We do this so that we can use the
                                    # pygame events in both the gui and
                                    # our program.
        app.run(events)
        app.draw()

### Arguments

theme
  The name of the theme you want to use. The name should correspond like so: path_to_project/data/themes/[themename]/ And within that folder there should be a config.txt file.